@@ -51,9 +51,7 @@ def determine_scaling(
     for _, batch in batches.items():
         if settings["robust"]:
             # TODO: consider f_iqr feature here. Would that work?
-            rnge = batch[columns_to_align].quantile(0.98) - batch[
-                columns_to_align
-            ].quantile(0.02)
+            rnge = batch[columns_to_align].quantile(0.98) - batch[columns_to_align].quantile(0.02)
         else:
             rnge = batch[columns_to_align].max() - batch[columns_to_align].min()
 
@@ -133,9 +131,7 @@ def reverse_scaling(
     for batch_id, batch in batches.items():
         out[batch_id] = batch[columns_to_align].copy()
         for tag, column in out[batch_id].iteritems():
-            out[batch_id][tag] = (
-                column * scale_df.loc[tag, "Range"] + scale_df.loc[tag, "Minimum"]
-            )
+            out[batch_id][tag] = column * scale_df.loc[tag, "Range"] + scale_df.loc[tag, "Minimum"]
     return out
 
 
@@ -241,9 +237,7 @@ def one_iteration_dtw(
     average_batch = refbatch_sc.copy().reset_index(drop=True) * 0.0
     successful_alignments = 0
 
-    for batch_id, batch in tqdm(
-        batches_scaled.items(), disable=not (settings["show_progress"])
-    ):
+    for batch_id, batch in tqdm(batches_scaled.items(), disable=not (settings["show_progress"])):
         try:
             # see Kassidas, page 180
             batch_subset = batch.iloc[:: int(settings["subsample"]), :]
@@ -331,9 +325,7 @@ def batch_dtw(
         default_settings.update(settings)
     settings = default_settings
     assert settings["maximum_iterations"] >= 3, "At least 3 iterations are required"
-    assert (
-        reference_batch in batches
-    ), "`reference_batch` was not found in the dict of batches."
+    assert reference_batch in batches, "`reference_batch` was not found in the dict of batches."
 
     assert check_valid_batch_dict(batches, no_nan=True)
 
@@ -372,9 +364,7 @@ def batch_dtw(
         # Deviations from the average batch:
         next_weights = np.zeros((1, refbatch_sc.shape[1]))
         for batch_id, result in aligned_batches.items():
-            next_weights += np.nansum(
-                np.power(result.synced - average_batch, 2), axis=0
-            )
+            next_weights += np.nansum(np.power(result.synced - average_batch, 2), axis=0)
             # TODO: use quadratic weights for now, but try sum of the absolute values instead
             #  np.abs(result.synced - average_batch).sum(axis=0)
 
@@ -387,9 +377,7 @@ def batch_dtw(
             # problematic_threshold = dist_df["Distance"].quantile(0.95)
 
         next_weights = 1.0 / np.where(next_weights > epsqrt, next_weights, 10000)
-        weight_vector = (
-            next_weights / np.sum(next_weights) * len(columns_to_align)
-        ).ravel()
+        weight_vector = (next_weights / np.sum(next_weights) * len(columns_to_align)).ravel()
         # If change in delta_weight is small, we terminate early; no need to fine-tune excessively.
         delta_weight = np.diag(weight_matrix) - weight_vector  # old - new
 
@@ -418,8 +406,7 @@ def batch_dtw(
         # Resample the trajectories of the aligned data now along this sequence.
         sequence = np.linspace(
             0,
-            settings["interpolate_time_axis_maximum"]
-            - settings["interpolate_time_axis_delta"],
+            settings["interpolate_time_axis_maximum"] - settings["interpolate_time_axis_delta"],
             synced.shape[0],
         )
         assert new_time_axis.min() == sequence.min()
@@ -533,24 +520,25 @@ def find_average_length(batches: Dict[str, pd.DataFrame], settings: dict = None)
 
     """
     default_settings = {
-        "robust": True,  # use robust scaling
+        "robust": True,  # use robust metric to calculate average batch length
     }
     if settings:
         default_settings.update(settings)
     settings = default_settings
 
-    batch_lengths = pd.Series(
-        {batch_id: df.shape[0] for batch_id, df in batches.items()}
-    )
+    batch_lengths = pd.Series({batch_id: df.shape[0] for batch_id, df in batches.items()})
     if settings["robust"]:
         # If multiple batches of the median length, return the last one.
-        return batch_lengths.index[
-            np.where((batch_lengths == batch_lengths.median()).values)[0][-1]
-        ]
+        try:
+            return batch_lengths.index[
+                np.where((batch_lengths == batch_lengths.median()).values)[0][-1]
+            ]
+        except IndexError:
+            # Very exceptional: if batch_lengths.median() is computed as the average of 2 numbers
+            # and therefore the median length batch doesn't actually exist
+            return find_average_length(batches, settings=dict(robust=False))
     else:
-        return batch_lengths.index[
-            (batch_lengths - batch_lengths.mean()).abs().argmin()
-        ]
+        return batch_lengths.index[(batch_lengths - batch_lengths.mean()).abs().argmin()]
 
 
 def find_reference_batch(
@@ -640,7 +628,7 @@ def find_reference_batch(
     )
     metrics = metrics.sort_values(by=["HT2", "SPE"])
     metrics = metrics.query(f"SPE < {pca_second.SPE_limit(0.5)}")
-    if settings['number_of_reference_batches'] == 1:
-        return metrics.index[0] # returns a single entry from the index
+    if settings["number_of_reference_batches"] == 1:
+        return metrics.index[0]  # returns a single entry from the index
     else:
-        return metrics.index[0:settings['number_of_reference_batches']]  # returns a list
+        return metrics.index[0 : settings["number_of_reference_batches"]]  # returns a list
